@@ -318,13 +318,20 @@ class OppConfigFileBase(MutableMapping):
         self._root: OppParser = root_cfg
         self._cfg_type = cfg_type
         self._sec = self._ensure_config_prefix(config_name)
+        self._sec_raw = config_name
         self._base_dir = _base_dir
 
         if not self._has_section_(self._sec):
             raise ValueError(f"no section found with name {self._sec}")
         self._parent_cfg = []
-        self._section_hierarchy = [self._ensure_config_prefix(self._sec)]
         self._is_parent = is_parent
+        self._section_hierarchy = [self._ensure_config_prefix(self._sec)]
+        self.update_selection_hierarchy()
+
+
+    def update_selection_hierarchy(self):
+        self._parent_cfg = []
+        self._section_hierarchy = [self._ensure_config_prefix(self._sec)]
         if not self._is_parent:
             stack = [iter(self.parents)]
             while stack:
@@ -338,8 +345,7 @@ class OppConfigFileBase(MutableMapping):
                         stack.append(iter(_pp.parents))
                 else:
                     stack.pop(0)
-
-        if config_name != "General" and self._has_section_("General"):
+        if self._sec_raw != "General" and self._has_section_("General"):
             self._parent_cfg.append(
                 OppConfigFileBase(self._root, "General", self._base_dir, is_parent=True)
             )
@@ -499,6 +505,8 @@ class OppConfigFileBase(MutableMapping):
                         return
         else:
             raise KeyError(f"key not found. Key: {k}")
+        if k == "extends":
+            self.update_selection_hierarchy()
 
     def __delitem__(self, k):
         if self._cfg_type.value < OppConfigType.EXT_DEL_LOCAL:
