@@ -120,6 +120,28 @@ class OppConfigFileBaseTest(unittest.TestCase):
         self.assertListEqual(
             opp.section_hierarchy, ["Config SlottedAlohaBase", "General"]
         )
+    
+    def test_hierarchy_update(self):
+        opp = self.get_object("SlottedAloha2b", OppConfigType.EDIT_LOCAL)
+        self.assertListEqual(
+            opp.section_hierarchy,
+            [
+                "Config SlottedAloha2b",
+                "Config SlottedAloha2",
+                "Config SlottedAlohaBase",
+                "Config HighTrafficSettings",
+                "General",
+            ],
+        )
+        opp["extends"] = "SlottedAlohaBase"
+        self.assertListEqual(
+            opp.section_hierarchy,
+            [
+                "Config SlottedAloha2b",
+                "Config SlottedAlohaBase",
+                "General",
+            ],
+        )
 
     def test_override(self):
         opp = self.get_object("SlottedAloha2", OppConfigType.EXT_DEL_LOCAL)
